@@ -22,8 +22,8 @@
 #include <cstring>
 #include <utility>
 
-#include <adbc.h>
-#include "adbc_driver_manager.h"
+#include "arrow-adbc/adbc.h"
+#include "arrow-adbc/adbc_driver_manager.h"
 
 #include "radbc.h"
 
